%global _with_test 0

Summary:        High-performance memory object caching system
Name:           memcached
Version:        1.5.6
Release:        %mkrel 1
License:        BSD
Group:          System/Servers
URL:            http://memcached.org/
Source0:        https://github.com/memcached/memcached/archive/%{version}/%{name}-%{version}.tar.gz
Source1:        %{name}-tmpfiles.conf
Source2:        memcached.sysconfig
Source3:        memcached.logrotate
Source4:        memcached@.service
Source5:        memcached.target
Requires(post):  systemd >= %{systemd_required_version}
Requires(post):  rpm-helper >= 0.24.8-1
Requires(preun): rpm-helper >= 0.24.8-1
Requires:       cyrus-sasl sasl-plug-plain sasl-plug-crammd5
BuildRequires:  autoconf2.5
BuildRequires:  automake
BuildRequires:  doxygen
BuildRequires:  libevent-devel
BuildRequires:  libsasl-devel 
BuildRequires:  cyrus-sasl 
BuildRequires:  sasl-plug-plain 
BuildRequires:  sasl-plug-crammd5
# Required by test suite
BuildRequires:  sasl-plug-sasldb
BuildRequires:  libxslt-proc
BuildRequires:  perl-devel

%description
memcached is a flexible memory object caching daemon designed to alleviate
database load in dynamic web applications by storing objects in memory. It's
based on libevent to scale to any size needed, and is  specifically optimized
to avoid swapping and always use non-blocking I/O.

%package        devel
Summary:        Files needed for development using memcached protocol
Group:          Development/C
Requires:       %{name} = %{version}-%{release}

%description    devel
Install memcached-devel if you are developing C/C++ applications that require
access to the memcached binary include files.

%prep
%setup -q

%build
./autogen.sh
%serverbuild

%configure2_5x \
%ifarch x86_64
--enable-extstore \
--enable-64bit
%endif
#disable extstore on 32bit, due to bug #319 (github)

#--enable-sasl
%make
make docs

%if %_with_test
%check
export PATH="$PATH:/sbin:/usr/sbin"
# whitespace tests fail locally on fedpkg systems now that they use git
rm -f t/whitespace.t

# Parts of the test suite only succeed as non-root.
if [ `id -u` -ne 0 ]; then
  # remove failing test that doesn't work in
  # build systems
  rm -f t/daemonize.t
fi
make test
%endif

%install
%makeinstall_std

install -m644 %{SOURCE1} -D %{buildroot}%{_tmpfilesdir}/%{name}.conf
install -m644 %{SOURCE2} -D %{buildroot}%{_sysconfdir}/sysconfig/%{name}
install -m644 %{SOURCE3} -D %{buildroot}%{_sysconfdir}/logrotate.d/%{name}
install -m755 scripts/%{name}-tool %{buildroot}%{_bindir}/%{name}-tool

install -m644 %{SOURCE4} -D %{buildroot}%{_unitdir}/%{name}@.service
install -m644 %{SOURCE5} -D %{buildroot}%{_unitdir}/%{name}.target

%post
%_tmpfilescreate %{name}
%_post_service %{name} %{name}.target

%preun
%_preun_service %{name} %{name}.target

%pre
%_pre_useradd %{name} /dev/null /bin/false

%postun
%_postun_userdel %{name}

%files
%doc AUTHORS* COPYING ChangeLog NEWS 
%doc doc/CONTRIBUTORS doc/protocol.txt doc/readme.txt
%config(noreplace) %{_sysconfdir}/sysconfig/%{name}
%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}
%{_bindir}/%{name}-tool
%{_bindir}/%{name}
%{_tmpfilesdir}/%{name}.conf
%{_unitdir}/%{name}*.service
%{_unitdir}/%{name}.target
%{_mandir}/man1/%{name}.1*

%files devel
%dir %{_includedir}/%{name}
%{_includedir}/%{name}/*.h


%changelog
* Sun Mar 11 2018 mokraemer <mokraemer> 1.5.6-1.mga6
  (not released yet)
+ Revision: 1208175
- Update memcached to 1.5.6 (mga#22688, CVE-2018-1000115, deadlock issues
- disabled UDP-Port (mga#22688)
+ shlomif <shlomif>
- Fix for MGA#22068 thanks to kekePower

* Mon Feb 13 2017 mrambo3501 <mrambo3501> 1.4.25-2.mga6
+ Revision: 1085989
- rebuild for new libevent

* Wed Nov 16 2016 neoclust <neoclust> 1.4.25-1.mga6
+ Revision: 1067548
- New version 1.4.25 + fix CVE-2016-870[4-6]

* Fri Feb 12 2016 umeabot <umeabot> 1.4.24-2.mga6
+ Revision: 956147
- Mageia 6 Mass Rebuild

* Thu Sep 10 2015 neoclust <neoclust> 1.4.24-1.mga6
+ Revision: 875324
- New version 1.4.24

* Wed Oct 15 2014 umeabot <umeabot> 1.4.17-3.mga5
+ Revision: 740976
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.4.17-2.mga5
+ Revision: 682352
- Mageia 5 Mass Rebuild

* Tue Jan 14 2014 oden <oden> 1.4.17-1.mga4
+ Revision: 566539
- 1.4.17 (fixes CVE-2013-0179, CVE-2013-7239, CVE-2013-7290, CVE-2013-7291)

* Mon Dec 30 2013 luigiwalser <luigiwalser> 1.4.15-6.mga4
+ Revision: 563337
- add upstream patch to fix CVE-2013-7239

* Fri Nov 22 2013 oden <oden> 1.4.15-3.mga4
+ Revision: 552293
- P0: security fix for CVE-2011-4971

* Mon Oct 21 2013 umeabot <umeabot> 1.4.15-2.mga4
+ Revision: 540662
- Mageia 4 Mass Rebuild

* Wed Oct 09 2013 dlucio <dlucio> 1.4.15-1.mga4
+ Revision: 494128
- filelist fix
- 1.4.15

* Sun Mar 24 2013 colin <colin> 1.4.13-7.mga3
+ Revision: 404859
- Add systemd requires and general post/pre fixes (mga#9302)

* Sat Jan 12 2013 umeabot <umeabot> 1.4.13-6.mga3
+ Revision: 359938
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Nov 25 2012 colin <colin> 1.4.13-5.mga3
+ Revision: 321726
- Use new macros for tmpfiles
- No need to pass in the templated unit name to the post_service helper

* Mon Aug 20 2012 colin <colin> 1.4.13-4.mga3
+ Revision: 282506
- Switch the .target to PartOf= rather than BindTo= now that we have systemd >= 188

* Mon Jul 23 2012 colin <colin> 1.4.13-3.mga3
+ Revision: 273742
- Add tmpfiles.d config to create PID dir
- Drop sysvinit script

* Fri Jun 08 2012 shlomif <shlomif> 1.4.13-2.mga3
+ Revision: 257589
- Bump release
- Convert tabs to spaces (rpmlint)
- Got rid of trailing space

* Fri Jun 08 2012 shlomif <shlomif> 1.4.13-1.mga3
+ Revision: 257582
- New version - 1.4.13
+ colin <colin>
- Implement a systemd target to easily control all memcache instances

* Sat Apr 28 2012 tmb <tmb> 1.4.11-3.mga2
+ Revision: 233790
- Require rpm-helper >= 0.24.8-1 for systemd support

* Mon Apr 02 2012 colin <colin> 1.4.11-2.mga2
+ Revision: 227942
- Bring sysconfig file and initscript into sync
- Add systemd (template) unit

* Tue Jan 31 2012 dmorgan <dmorgan> 1.4.11-1.mga2
+ Revision: 203721
- New version 1.4.11
  Disable sasl support ( need to fix build )
  Disable tests ( need to be fixed )

* Mon Jan 24 2011 erwan <erwan> 1.4.5-6.mga1
+ Revision: 37960
- imported package memcached

